{% load staticfiles %}
{% load autodocs_filters %}

<!doctype html>
<html class="no-js" lang="en">
<head>
    <meta charset="utf-8">
    <meta http-equiv="x-ua-compatible" content="ie=edge">
    <title>DRF Auto Docs</title>
    <meta name="description" content="Django REST framework automatic api generator">
    <meta name="keywords" content="Django REST framework automatic api generator">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
    <link rel="stylesheet" href="{% static 'css/materialize.min.css' %}">
    <link rel="stylesheet" href="{% static 'css/custom.css' %}">
    <link rel="shortcut icon" href="{% static 'img/favicon.ico' %}" type="image/x-icon">
    <link rel="icon" href="{% static 'img/favicon.ico' %}" type="image/x-icon">
</head>
<body class="main-color">
<a href="https://github.com/iMakedonsky/drf-autodocs" class="github-corner" aria-label="View source on Github"><svg width="80" height="80" viewBox="0 0 250 250" style="fill:#FD6C6C; color:#fff; position: absolute; top: 0; border: 0; right: 0;" aria-hidden="true"><path d="M0,0 L115,115 L130,115 L142,142 L250,250 L250,0 Z"></path><path d="M128.3,109.0 C113.8,99.7 119.0,89.6 119.0,89.6 C122.0,82.7 120.5,78.6 120.5,78.6 C119.2,72.0 123.4,76.3 123.4,76.3 C127.3,80.9 125.5,87.3 125.5,87.3 C122.9,97.6 130.6,101.9 134.4,103.2" fill="currentColor" style="transform-origin: 130px 106px;" class="octo-arm"></path><path d="M115.0,115.0 C114.9,115.1 118.7,116.5 119.8,115.4 L133.7,101.6 C136.9,99.2 139.9,98.4 142.2,98.6 C133.8,88.0 127.5,74.4 143.8,58.0 C148.5,53.4 154.0,51.2 159.7,51.0 C160.3,49.4 163.2,43.6 171.4,40.1 C171.4,40.1 176.1,42.5 178.8,56.2 C183.1,58.6 187.2,61.8 190.9,65.4 C194.5,69.0 197.7,73.2 200.1,77.6 C213.8,80.2 216.3,84.9 216.3,84.9 C212.7,93.1 206.9,96.0 205.4,96.6 C205.1,102.4 203.0,107.8 198.3,112.5 C181.9,128.9 168.3,122.5 157.7,114.1 C157.9,116.9 156.7,120.9 152.7,124.9 L141.0,136.5 C139.8,137.7 141.6,141.9 141.8,141.8 Z" fill="currentColor" class="octo-body"></path></svg></a><style>.github-corner:hover .octo-arm{animation:octocat-wave 560ms ease-in-out}@keyframes octocat-wave{0%,100%{transform:rotate(0)}20%,60%{transform:rotate(-25deg)}40%,80%{transform:rotate(10deg)}}@media (max-width:500px){.github-corner:hover .octo-arm{animation:none}.github-corner .octo-arm{animation:octocat-wave 560ms ease-in-out}}</style>


<h1 class="center-align">DRF Auto Docs</h1>
<h4 class="center-align">Completely automated api docs for django-rest-framework</h4>
<br>


<ul class="collapsible legend"><li>
    <div class="collapsible-header waves-effect waves-light main-color">
        API help
    </div>
    <div class="collapsible-body">
        <div class="row tabs-wrapper">
            <div class="col s12">
                <ul class="tabs">
                    <li class="tab col s3"><a class="waves-effect waves-light" href="#api-general">General</a></li>
                    <li class="tab col s3"><a class="waves-effect waves-light" href="#api-fields">Fields</a></li>
                    <li class="tab col s3"><a class="waves-effect waves-light" href="#api-choices">Choices</a></li>
                </ul>
            </div>
            <div id="api-general" class="col s12 tab-content">
                This is short description of how this API doc works. Click other tabs to see concrete topic.
            </div>
            <div id="api-fields" class="col s12 tab-content">
                <ul>
                    <li>
                        <span class="new badge red" data-badge-caption="">Item structure</span>
                         &nbsp - click these to see nested items structure
                    </li>
                    <li>
                        <span class="new badge red" data-badge-caption="">Required</span>
                         &nbsp - without this field, endpoint wont work
                    </li>
                    <li>
                        <span class="new badge green" data-badge-caption="">
                            <a class="tooltipped white-text"
                               data-position="bottom"
                               data-delay="50"
                               data-tooltip="Some extra information from backend developer may be there!"
                            >
                                Help Text
                            </a>
                        </span>
                        &nbsp - hover over these things to see what's within
                    </li>
                </ul>
            </div>
            <div id="api-choices" class="col s12 tab-content">
                <p>To see ChoiceField choices, click on <span class="new badge green darken-3" data-badge-caption="">Choices</span>
                </p>
                <br/>
                <p>In choices you'll see 2 things: <b>"value"</b> and <b>"meaning"</b>.</p>
                <p>
                    <b>"Meaning"</b> is human-understandable description of value.
                    It's used only for choice field rendering, but doesn't take any part
                    in logic/data processing.
                </p>
            </div>
        </div>
    </div>
</li></ul>


<div class="container">
    {% include 'drf_autodocs/components/tree_node.html' with endpoints_tree=endpoints_tree %}
</div>


<script src="{% static 'js/jquery-2.1.1.min.js' %}"></script>
<script src="{% static 'js/materialize.min.js' %}"></script>
<script>

{#    collapse interface for ListSerializer #}
    $('.subfields-wrapper > .badge, .subfields-wrapper > .btn').click(function(){
        var subfields = $(this).next();
        if (subfields.is(':visible')) {
            subfields.hide(300);
        } else {
            subfields.show(300);
        }
    });


{#    dynamically activate dropdowns as they need to have unique ids    #}
    var buttons = $('a.dropdown-button');
    var dropdowns = $('ul.dropdown-content');
    for (var i=0; i<buttons.length; i++) {
        buttons[i].setAttribute('data-activates', 'dropdown-' + i);
        dropdowns[i].id = 'dropdown-' + i;
    }
    buttons.dropdown({
            inDuration: 300,
            outDuration: 225,
            constrain_width: false, // Does not change width of dropdown to that of the activator
            hover: true, // Activate on hover
            gutter: 0, // Spacing from edge
            belowOrigin: false, // Displays dropdown below the button
            alignment: 'left' // Displays dropdown with edge aligned to the left of button
        }
    );
$(document).ready(function(){
    $('ul.tabs').tabs();
});
</script>
</body>
</html>