.legend {
    position: fixed;
    top: 20px;
    left: 20px;
    z-index: 5;
}
.legend .collapsible-header {
    background: #FD6C6C !important;
    font-weight: bolder;

}
.legend .collapsible-body{
    width: 800px;
}
.endpoints-list {
    margin-left: 60px;
}
.endpoints-list > li {
    margin-left: 60px;
}
code {
    background-color: grey;
    padding: 5px;
    border-radius: 4px;
}
.field-list > li {
    margin-left: 30px;
    width: 100%;
}
.field-list > li > * {
    vertical-align: top;
}
.field-list li span:last-child {
    margin-right: 20px;
}
span.badge {
    vertical-align: top;
    top: 2px;
}
span.badge > a {
    vertical-align: top;
}
.collapsible-body p {
    padding: 0;
}
.collapsible-body {
    box-shadow: 0 0 3px 2px rgba(255,255,255,1);
    padding: 20px;
}
.collapsible {
    border: 0;
}

.collapsible-header {
    border: 0;
    box-shadow: 0 0 3px 2px rgba(255,255,255,1);
    z-index: auto;
}
.collapsible span.badge.new {
    z-index: auto;
}

.json-container {
    border-radius: 10px;
    padding: 10px;
    margin-left: 30px;
    display: inline-block;
    box-sizing: padding-box;
}
td {
    border: 1px solid white !important;
}
.badge {
    float: none !important;
    font-weight: bold !important;
}
.btn-method {
    padding: 0 1rem;
    margin-top: -2.5px
}
.get {
    background-color: #2ecc71 !important;
}
.post {
    background-color: #2980b9 !important;
}
.put, .patch {
    background-color: #16a085 !important;
}
.delete {
    background-color: #c0392b !important;
}
.options {
    background-color: #95a5a6 !important;
}
div.subfields-wrapper {
    display: inline-block;
}
.subfields {
    display: none;
}
.tabs {
    font-weight: bold;
    background: transparent;
}
.tabs-wrapper > .col {
    padding: 0;
}
.tabs-wrapper > .tab-content {
    padding: 20px;
}
.tabs > div {
    margin-left: 10px;
    margin-right: 10px;
}
.tabs .tab a {
    color: white !important;
}
.indicator {
    display: none !important;
}
.tabs .active {
    background-color: #360066 !important;
}
.choices-header {
    font-weight: bolder;
}
.active {
    background: #6B00CC !important;
}
/*==================================================*/
body {
    color: white !important;
}





/**
 * Framework starts from here ...
 * ------------------------------
 */

.tree,
.tree ul.tree-list {
    margin:0 0 0 1em; /* indentation */
    padding:0;
    list-style:none;
    position:relative;
}

.tree ul.tree-list {margin-left:.5em} /* (indentation/2) */

.tree:before,
.tree ul.tree-list:before {
    content:"";
    display:block;
    width:0;
    position:absolute;
    top:0;
    bottom:0;
    left:0;
    border-left: 3px solid;
}

.tree li.tree-list-item {
    margin:0;
    padding-left: 1.5em;
    position:relative;
}

.tree li.tree-list-item:before {
    content:"";
    display:block;
    width: 20px; /* same with indentation */
    height: 0;
    border-top:3px solid;
    margin-top:-3px; /* border top width */
    position:absolute;
    top:1em; /* (line-height/2) */
    left:0;
}

.tree li.tree-list-item:last-child:before {
    background: #220040 !important;
    height:auto;
    top:1em; /* (line-height/2) */
    bottom:0;
}
.main-color {
    background: #220040 !important;
}
.tab-content {
    background: #360066 !important;
}